@@ -54,7 +54,7 @@ class DMMProperty(Enum):
     UNIT_INTERFACING = 3
 
 
-class Method:  # pylint: disable=R0902
+class Method:
     """
     This class represents a method in a class. Contains various information
     extracted through Lizard.
@@ -133,7 +133,7 @@ class Method:  # pylint: disable=R0902
         return len(self.parameters) <= Method.UNIT_INTERFACING_LOW_RISK_THRESHOLD
 
 
-class Modification:  # pylint: disable=R0902
+class Modification:
     """
     This class contains information regarding a modified file in a commit.
     """
@@ -156,7 +156,7 @@ class Modification:  # pylint: disable=R0902
         self._nloc = None
         self._complexity = None
         self._token_count = None
-        self._function_list = [] # type: List[Method]
+        self._function_list = []  # type: List[Method]
         self._function_list_before = []  # type: List[Method]
 
     @property
@@ -276,7 +276,7 @@ class Modification:  # pylint: disable=R0902
         :return: Dictionary
         """
         lines = self.diff.split('\n')
-        modified_lines = {'added': [], 'deleted': []} # type: Dict[str, List[Tuple[int, str]]]
+        modified_lines = {'added': [], 'deleted': []}  # type: Dict[str, List[Tuple[int, str]]]
 
         count_deletions = 0
         count_additions = 0
@@ -478,6 +478,15 @@ class Commit:
         """
         return Path(self._conf.get('path_to_repo')).name
 
+    @property
+    def project_path(self) -> str:
+        """
+        Return the absolute path of the project.
+
+        :return: project path
+        """
+        return str(Path(self._conf.get('path_to_repo')))
+
     @property
     def author_date(self) -> datetime:
         """
@@ -719,7 +728,6 @@ class Commit:
         The DMM value is computed as the proportion of good change in the commit:
         Good changes: Adding low risk code or removing high risk codee.
         Bad changes: Adding high risk code or removing low risk code.
-        Furthermore, the special case where only low risk code is removed is also given the highest score.
 
         :param dmm_prop: Property indicating the type of risk
         :return: dmm value (between 0.0 and 1.0) for the property represented in the property.
@@ -727,14 +735,7 @@ class Commit:
         delta_profile = self._delta_risk_profile(dmm_prop)
         if delta_profile:
             (delta_low, delta_high) = delta_profile
-            dmm = self._good_change_proportion(delta_low, delta_high)
-            if delta_low < 0 and delta_high == 0:
-                assert dmm == 0.0
-                # special case where removal of good (low risk) code is OK.
-                # re-adjust dmm accordingly:
-                dmm = 1.0
-            assert 0.0 <= dmm <= 1.0
-            return dmm
+            return self._good_change_proportion(delta_low, delta_high)
         return None
 
     def _delta_risk_profile(self, dmm_prop: DMMProperty) -> Optional[Tuple[int, int]]:
@@ -748,20 +749,20 @@ class Commit:
         """
         supported_modifications = [mod for mod in self.modifications if mod.language_supported]
         if supported_modifications:
-            deltas = [mod._delta_risk_profile(dmm_prop) for mod in supported_modifications]  #pylint: disable=W0212
+            deltas = [mod._delta_risk_profile(dmm_prop) for mod in supported_modifications]
             delta_low = sum(dlow for (dlow, dhigh) in deltas)
             delta_high = sum(dhigh for (dlow, dhigh) in deltas)
             return delta_low, delta_high
         return None
 
     @staticmethod
-    def _good_change_proportion(low_risk_delta: int, high_risk_delta: int) -> float:
+    def _good_change_proportion(low_risk_delta: int, high_risk_delta: int) -> Optional[float]:
         """
         Given a delta risk profile, compute the proportion of "good" change in the total change.
         Increasing low risk code, or decreasing high risk code, is considered good.
         Other types of changes are considered not good.
 
-        :return: proportion of good change in total change.
+        :return: proportion of good change in total change, or None if the total change is zero.
         """
         bad_change, good_change = (0, 0)
 
@@ -777,12 +778,14 @@ class Commit:
         assert good_change >= 0 and bad_change >= 0
 
         total_change = good_change + bad_change
-        result = good_change / total_change if total_change > 0 else 1.0
-        assert 0.0 <= result <= 1.0
+        if total_change == 0:
+            proportion = None
+        else:
+            proportion = good_change / total_change
+            assert 0.0 <= proportion <= 1.0
 
-        return result
+        return proportion
 
-    # pylint disable=R0902
     @staticmethod
     def _from_change_to_modification_type(diff: Diff):
         if diff.new_file:
